<?php
function _updatePictures(&$tof,$vars) {
	updatePictures(
		$tof,
		$vars['ParentTopicID'],
		$vars['Groups'],
		$vars['Pictures']);
}

/* update the groups and topic of a set of pictures */
function updatePictures(&$tof,$parentTopicID, $groups, $pictures) {
	$nbUpdatedPictures = 0;
	if (!is_array($pictures)) {
		return 0;
	}
	if ($groups=="unchanged" || in_array("unchanged",$groups)) {
		$groups = "";
	} else if (!is_array($groups)) {
		$groups = array();
	}

	$topics="";
	if ($parentTopicID!='unchanged') {
		$topics = array($parentTopicID);
	}

	foreach($pictures as $pictureID) {
		$arr = array("PictureID" => $pictureID);
		$nbUpdatedPictures += $tof->ct->updatePicture($arr,$topics,$groups,
		$tof->uid);
	}
	return $nbUpdatedPictures;
}

?>